@@ -107,9 +107,9 @@ class DBAPICursor(with_metaclass(abc.ABCMeta, object)):
         if not self._data:
             return None
         else:
-            # if self._rownumber == 1000:
-            #     _logger.info("Commons - Breaking the loop after 1000 records")
-            #     return None
+            if self._rownumber <= 1000:
+                _logger.info("Commons - Breaking the loop after 1000Commons - fetch many records")
+                return None
             self._rownumber += 1
             return self._data.popleft()
 
@@ -125,6 +125,7 @@ class DBAPICursor(with_metaclass(abc.ABCMeta, object)):
         """
         _logger.info("Commons - fetch many.... size - {}".format(size))
         rowsToReturn = self.fetchone()
+
         if rowsToReturn is None:
             return list()
         return list(rowsToReturn)
